@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Cookies API for Server & Client - ~/lib/Cookie/Domain.pm
-## Version v0.1.1
-## Copyright(c) 2021 DEGUEST Pte. Ltd.
+## Version v0.1.2
+## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/05/06
-## Modified 2022/06/22
+## Modified 2022/06/23
 ## You can use, copy, modify and  redistribute  this  package  and  associated
 ## files under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
@@ -41,7 +41,7 @@ BEGIN
             )*
         )
     $/x;
-    our $VERSION = 'v0.1.1';
+    our $VERSION = 'v0.1.2';
 };
 
 use strict;
@@ -422,7 +422,7 @@ sub save_as_json
     my $dt_fmt = DateTime::Format::Strptime->new(
         pattern => '%FT%T%z',
         locale => 'en_GB',
-        time_zone => 'local',
+        time_zone => $tz->name,
     );
     my $today = DateTime->now( time_zone => $tz, formatter => $dt_fmt );
     my $meta  = $self->meta;
@@ -662,7 +662,7 @@ Cookie::Domain - Domain Name Public Suffix Query Interface
 
 =head1 VERSION
 
-    v0.1.1
+    v0.1.2
 
 =head1 DESCRIPTION
 
