@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Cookies API for Server & Client - ~/lib/Cookie/Jar.pm
-## Version v0.1.3
+## Version v0.1.4
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/10/08
-## Modified 2022/06/23
+## Modified 2022/06/27
 ## You can use, copy, modify and  redistribute  this  package  and  associated
 ## files under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
@@ -39,7 +39,7 @@ BEGIN
     use Nice::Try;
     use Scalar::Util;
     use URI::Escape ();
-    our $VERSION = 'v0.1.3';
+    our $VERSION = 'v0.1.4';
     # This flag to allow extensive debug message to be enabled
     our $COOKIES_DEBUG = 0;
     use constant CRYPTX_VERSION => '0.074';
@@ -166,15 +166,23 @@ sub add_request_header
     # my $now = time();
     my $now = DateTime->now;
     $path = $self->_normalize_path( $path ) if( CORE::index( $path, '%' ) != -1 );
-    my $dom = Cookie::Domain->new || return( $self->pass_error( Cookie::Domain->error ) );
-    my $res = $dom->stat( $host );
-    return( $self->pass_error( $dom->error ) ) if( !defined( $res ) );
-    if( !CORE::length( $res ) || ( $res && !$res->domain->length ) )
+    my $root;
+    if( $self->_is_ip( $host ) )
     {
-        $self->message( 3, "No root domain found for host \"$host\"." );
-        return( $self->error( "No root domain found for host \"$host\"." ) );
+        $root = $host;
+    }
+    else
+    {
+        my $dom = Cookie::Domain->new || return( $self->pass_error( Cookie::Domain->error ) );
+        my $res = $dom->stat( $host );
+        return( $self->pass_error( $dom->error ) ) if( !defined( $res ) );
+        if( !CORE::length( $res ) || ( $res && !$res->domain->length ) )
+        {
+            $self->message( 3, "No root domain found for host \"$host\"." );
+            return( $self->error( "No root domain found for host \"$host\"." ) );
+        }
+        $root = $res->domain;
     }
-    my $root = $res->domain;
     # rfc6265, section 5.4
     # "Either:
     # The cookie's host-only-flag is true and the canonicalized request-host is identical to the cookie's domain.
@@ -477,17 +485,25 @@ sub extract
     }
     $path = '/' unless( length( $path ) );
     $port = $uri->port if( !defined( $port ) || !length( $port ) );
-    my $dom = Cookie::Domain->new || return( $self->pass_error( Cookie::Domain->error ) );
-    $self->message( 3, "Guessing root domain for host '$host'." ) if( $COOKIES_DEBUG );
-    my $res = $dom->stat( $host );
-    if( !defined( $res ) )
+    my $root;
+    if( $self->_is_ip( $host ) )
     {
-        $self->message( 3, "Error found while trying to get root domain for host \"$host\"." ) if( $COOKIES_DEBUG );
-        return( $self->pass_error( $dom->error ) );
+        $root = $host;
+    }
+    else
+    {
+        my $dom = Cookie::Domain->new || return( $self->pass_error( Cookie::Domain->error ) );
+        $self->message( 3, "Guessing root domain for host '$host'." ) if( $COOKIES_DEBUG );
+        my $res = $dom->stat( $host );
+        if( !defined( $res ) )
+        {
+            $self->message( 3, "Error found while trying to get root domain for host \"$host\"." ) if( $COOKIES_DEBUG );
+            return( $self->pass_error( $dom->error ) );
+        }
+        # Possibly empty
+        $self->message( 3, "No root found in public suffix for host \"$host\"." ) if( !$res );
+        $root = $res ? $res->domain : '';
     }
-    # Possibly empty
-    $self->message( 3, "No root found in public suffix for host \"$host\"." ) if( !$res );
-    my $root = $res ? $res->domain : '';
     
     foreach my $o ( @$all )
     {
@@ -1614,7 +1630,7 @@ Cookie::Jar - Cookies API for Server & Client
 
 =head1 VERSION
 
-    v0.1.3
+    v0.1.4
 
 =head1 DESCRIPTION
 
